% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dobserv_funcs.R
\name{dobserv_indep_obs}
\alias{dobserv_indep_obs}
\title{runs double-observer analysis for independent observers}
\usage{
dobserv_indep_obs(dobsdata, model = ~obs, obscov = NULL)
}
\arguments{
\item{dobsdata}{data frame with the following fields:
\itemize{
 \item \code{obs} observer number for primary observer
 \item \code{species} name of species
 \item \code{X10} number of individuals of species detected by observer 1
 and missed by observer 2
 \item \code{X01} number of individuals of species missed by observer 1
 and detected by observer 2
 \item \code{X11} number of individuals of species detected by both observers
 }}

\item{model}{list of model definitions. Model definitions are in GLM form.
 \itemize{
 \item \code{~1} means detection is constant for all observers and species.
 \item \code{~sp} means detection varies by species (constant across observers)
 \item \code{~obs} means detection varies by observer (constant across species)
 \item \code{~sp*obs} means detection varies by species and observer
 \item \code{~xxxx} means detection varies by input covariate, xxxx
}}

\item{obscov}{Covariates which differ by observer.}
}
\value{
list containing max log-like, estimates of p, std.err of p,
         gradient, hessian, completion code, num-iterations, model name,
         analys type, design matrix, estimated N and std.err,
         AIC, G-stat.
}
\description{
\code{dobserv_indep_obs} returns aic table of results
}
\note{
Covariates which are the same for both observers should be included
in the input data-frame.  Covariates which differ by observer
should be included as a separate data-frame (with twice the
number of rows as the input data).
}
\examples{
#
\dontrun{

fname=system.file('extdata','sample3.csv',package='dobserv')

 #  read sample data file which includes a covariate (temperature) in the last column
d3=read.csv(fname,header=F,skip=1); colnames(d3)=c('obs','sp','X10','X01','X11','temp')
 #  run a few models...
z1=dobserv_indep_obs(d3,model=~obs)
z2=dobserv_indep_obs(d3,model=~temp*obs)
 #  print estimates from 2nd model for each species...
print(round(z2$z,4))
 #  print estimate of total number of individuals...
print(round(z2$ntotal,4))
 }
}
\seealso{
dobserv_dep_obs
}
\author{
Jim Hines
}
